pub struct GetBatchUserFee {
pub currency_pairs: String,
pub credentials: Option<Credentials>,
}Expand description
Request for retrieving trading fees for multiple currency pairs
Fields
currency_pairs: StringComma-separated list of currency pairs to get fees for
credentials: Option<Credentials>API credentials for authentication
Implementations
Sourceimpl GetBatchUserFee
impl GetBatchUserFee
Sourcepub fn new(currency_pairs: &str) -> Self
pub fn new(currency_pairs: &str) -> Self
Creates a new GetBatchUserFee request with currency pairs
Sourcepub fn credentials(self, creds: Credentials) -> Self
pub fn credentials(self, creds: Credentials) -> Self
Sets the API credentials for authentication