RequestBuilder

Struct RequestBuilder 

pub struct RequestBuilder { /* private fields */ }
API HTTP Request

A low-level request builder for API integration decoupled from any specific underlying HTTP library.

Implementations

Source

impl RequestBuilder

pub fn new(method: Method, path: &str) -> Self

Creates a new request builder with method and path

pub fn params<'a>( self, params: impl IntoIterator<Item = (&'a str, &'a str)>, ) -> Self

Append params to the request’s query string. Parameters may share the same key, and will result in a query string with one or more duplicated query parameter keys.

pub fn payload(self, payload: &str) -> Self

Sets the request body payload

pub fn credentials(self, credentials: Credentials) -> Self

Sets the API credentials for authentication

pub fn x_gate_exp_time(self, x_gate_exp_time: u128) -> Self

Sets the Gate expiration time

pub fn sign(self) -> Self

Marks this request to be signed with HMAC