pub struct RequestBuilder { /* private fields */ }Expand description
API HTTP Request
A low-level request builder for API integration decoupled from any specific underlying HTTP library.
Implementations
Sourceimpl RequestBuilder
impl RequestBuilder
Sourcepub fn new(method: Method, path: &str) -> Self
pub fn new(method: Method, path: &str) -> Self
Creates a new request builder with method and path
Sourcepub fn params<'a>(
self,
params: impl IntoIterator<Item = (&'a str, &'a str)>,
) -> Self
pub fn params<'a>( self, params: impl IntoIterator<Item = (&'a str, &'a str)>, ) -> Self
Append params to the request’s query string. Parameters may
share the same key, and will result in a query string with one or
more duplicated query parameter keys.
Sourcepub fn credentials(self, credentials: Credentials) -> Self
pub fn credentials(self, credentials: Credentials) -> Self
Sets the API credentials for authentication
Sourcepub fn x_gate_exp_time(self, x_gate_exp_time: u128) -> Self
pub fn x_gate_exp_time(self, x_gate_exp_time: u128) -> Self
Sets the Gate expiration time